@@ -7,7 +7,7 @@
 #' @param r Use a value between 0 and 1. Default is 0.6. This is a user defined correlation cut-off to perform feature selection (\code{\link{feature_select}}). Feature selection aids to enrich the prediction of relative abundance of immune cells by filtering off poorly correlated ImSig genes. To get an idea of what cut-off to use check the results of (\code{\link{gene_stat}}) and choose a cut-off that displays high median correlation and maintains a high proportion of genes after feature selection.
 #' @return Hazard Ratio
 #' @examples \donttest{
-#' survival = imsig_survival (exp = example_data)
+#' survival = imsig_survival (exp = example_data, cli = example_cli)
 #' head(survival)
 #' }
 #' @import survival
@@ -23,9 +23,9 @@ imsig_survival <- function(exp, cli, time = 'time', status= 'status', r = 0.6){
   cell_cli <- cell_cli[,-1]
   HR <- data.frame()
   for (i in 1: length(levels(sig$cell))){
-    cell_ordered <- cell_cli[order(cell_cli[,i]),]
+    cell_ordered <- cell_cli[unlist(sort.list(cell_cli[,i])),]
     cell_ordered$group <- ifelse(cell_ordered[,i] <= median(cell_cli[,i]), "low", "high")
-    cox <- coxph(Surv(time, status) ~ group, cell_ordered)
+    cox <- survival::coxph(Surv(time, status) ~ group, cell_ordered)
     x <- summary(cox)[8]
     HR.OS <- data.frame(log2(x[[1]][1]))
     HR.UP <- data.frame(log2(x[[1]][4]))
