@@ -5,7 +5,8 @@
 
 pp_exp <- function(exp){
   sig <- sig
-  g <- Reduce(intersect, list(as.character(row.names(exp), sig$gene)))
+  #g <- Reduce(intersect, list(as.character(row.names(exp), sig$gene)))
+  g <- intersect(row.names(exp), as.character(sig$gene))
   exp <- exp [as.character(g),]
   return(exp)
 }
