@@ -4,7 +4,8 @@
 #' @return ImSig dataframe
 
 pp_sig <- function(exp){
-  g <- Reduce(intersect, list(as.character(row.names(exp), sig$gene)))
+  #g <- Reduce(intersect, list(as.character(row.names(exp), sig$gene)))
+  g <- intersect(row.names(exp), as.character(sig$gene))
   sig <- sig[sig$gene %in% as.character(g),]
   return(sig)
 }
